@@ -1,9 +1,14 @@
-# $Id: RankCorrelation.pm 802 2007-12-03 22:16:27Z gene $
-
 package Statistics::RankCorrelation;
-our $VERSION = '0.1203';
+BEGIN {
+  $Statistics::RankCorrelation::AUTHORITY = 'cpan:GENE';
+}
+# ABSTRACT: Compute the rank correlation between two vectors
+
 use strict;
 use warnings;
+
+our $VERSION = '0.1204';
+
 use Carp;
 
 sub new {
@@ -23,7 +28,6 @@ sub _init {
         if( ref $arg eq 'ARRAY' ) {
                if( !defined $self->x_data ) { $self->x_data( $arg ) }
             elsif( !defined $self->y_data ) { $self->y_data( $arg ) }
-            # XXX Handle extra data. Thanks. Love, Gene.
         }
         elsif( !ref $arg ) {
             my $v = shift;
@@ -197,7 +201,7 @@ sub csim {
     return $k / (@$m1 * @$m1);
 }
 
-sub pad_vectors { # Append zeros to either vector for all values in the other that do not have a corresponding value.
+sub pad_vectors {
     my ($u, $v) = @_;
 
     if (@$u > @$v) {
@@ -210,7 +214,7 @@ sub pad_vectors { # Append zeros to either vector for all values in the other th
     return $u, $v;
 }
 
-sub correlation_matrix { # Build a square, binary matrix that represents "higher or lower" value within the given vector.
+sub correlation_matrix {
     my $u = shift;
     my $c;
 
@@ -224,7 +228,7 @@ sub correlation_matrix { # Build a square, binary matrix that represents "higher
     return $c;
 }
 
-sub kendall { # Return Kendall's tau correlation coefficient
+sub kendall {
     my $self = shift;
 
     # Calculate number of concordant and discordant pairs.
@@ -264,9 +268,17 @@ sub sign {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-Statistics::RankCorrelation - Compute the rank correlation between two vectors 
+Statistics::RankCorrelation - Compute the rank correlation between two vectors
+
+=head1 VERSION
+
+version 0.1204
 
 =head1 SYNOPSIS
 
@@ -489,15 +501,15 @@ Jon Schutz E<lt>Jon.Schutz@youramigo.comE<gt>
 
 Andy Lee E<lt>yikes2000@yahoo.comE<gt>
 
-=head1 AUTHOR AND COPYRIGHT
+=head1 AUTHOR
 
-Gene Boggs E<lt>gene@cpan.orgE<gt>
+Gene Boggs <gene@cpan.org>
 
-Copyright 2010, Gene Boggs, All Rights Reserved.
+=head1 COPYRIGHT AND LICENSE
 
-=head1 LICENSE
+This software is copyright (c) 2015 by Gene Boggs.
 
-This program is free software; you can redistribute or modify it under
-the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
